@@ -1,27 +1,18 @@
-/*
- * This file is part of the KDE project.
- * Copyright © 2010 Michael Pyne <mpyne@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*  This file is part of the KDE project.
+    SPDX-FileCopyrightText: 2010 Michael Pyne <mpyne@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #ifndef KLOCALIMAGECACHEIMPL_H
 #define KLOCALIMAGECACHEIMPL_H
 
 #include <kguiaddons_export.h>
 
+#include <memory>
+
+class KLocalImageCacheImplementationPrivate;
+
 class QImage;
 class QPixmap;
 class QByteArray;
@@ -36,7 +27,7 @@ class QString;
 class KGUIADDONS_EXPORT KLocalImageCacheImplementation
 {
 private:
-    KLocalImageCacheImplementation(unsigned defaultCacheSize);
+    explicit KLocalImageCacheImplementation(unsigned defaultCacheSize);
 
 public:
     virtual ~KLocalImageCacheImplementation();
@@ -58,8 +49,7 @@ protected:
     void clearLocalCache();
 
 private:
-    class Private;
-    Private *const d; ///< @internal
+    std::unique_ptr<KLocalImageCacheImplementationPrivate> const d; ///< @internal
 
     template<class T> friend class KSharedPixmapCacheMixin;
 };
